Plugin: JS9Panner

### JS9 Panner

The Panner plugin will displays the full image along with a viewport rectangle showing the currently displayed image section in the primary image window. The viewport can be moved around in order to pan to different locations in the primary image. The panner also has command button options to zoom the viewport itself. (This makes the viewport rectangle larger at the expense of displaying only a section of the full image. It is useful for panning in a very large image.)

The WCS orientation (North and East) are shown on the display. You can turn off direction display by changing the value of the JS9.globalOpts.pannerDirections property, either by using the Preferences plugin or, for site-wide configuration, by changing the value in the js9prefs.js file.